// UcigameJavaVersion15Checker  (September, 2007)

// Code in ucigame.jar is compiled to be compatible with Java 1.5
// (class version 49.0):
//
//     javac -target 1.5 ucigame/*.java
//
// If a browser has a version of Java earlier than 1.5, an exception
// will be thrown, usually java.lang.UnsupportedClassVersionError.
// The user will not see the Ucigame game, and Ucigame cannot
// catch and handle this error, because the Ucigame class
// can't be run by the browser's version of Java.

// There is no satisfactory solution, but with this applet the user
// can be told what is going on.  Make sure this applet is compiled with:
//
//     javac -source 1.2 -target 1.1 UcigameJavaVersion15Checker.java
//
// UcigameJavaVersion15Checker will then be compatible with versions of
// Java going back to 1.1.  Put the following HTML in the same web
// page that has the Ucigame game:
//
//     <applet code="UcigameJavaVersion15Checker.class"
//	    codebase="." width="1" height="1">
//     </applet>
//
// If the Java version is 1.5 or later, then this applet will not
// display a window and will be invisible to the user.  If the Java
// version is earlier than 1.5, then this applet will pop up a
// new window with a short explanation of why the game cannot run.


import java.applet.*;
import java.awt.*;
import java.awt.event.*;

public class UcigameJavaVersion15Checker extends Applet
						implements ActionListener
{
	private Frame frame;

	public void start()
	{
		String version = System.getProperty("java.version");
		if (version.compareTo("1.5") < 0)
		{
			System.out.println("UcigameJavaVersion15Checker: version " +
						version + " is less than 1.5");
		}
		else
		{
			System.out.println("UcigameJavaVersion15Checker: version " +
						version + " is OK");
			return;	// nothing put on screen
		}

		frame = new Frame("Ucigame Java Version 1.5 Checker");
		frame.setSize(300, 175);
		frame.setLayout(null);

		Label l1 = new Label("The game applet may not display");
		Label l2 = new Label("because your browser's version of Java");
		Label l3 = new Label("is older than Java 1.5.");

		l1.setBounds(20, 40, 280, 15);
		l2.setBounds(20, 58, 280, 15);
		l3.setBounds(20, 76, 280, 15);

		frame.add(l1);
		frame.add(l2);
		frame.add(l3);

		Button butt = new Button("OK");
		butt.setBounds(100, 100, 40, 25);
		butt.addActionListener(this);
		frame.add(butt);

		frame.setVisible(true);

		showStatus("Game failed because browser's version of Java is " + version);
	}

	public void actionPerformed(ActionEvent event)
	{
		frame.setVisible(false);
	}

}